#
# spec file for package console
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           console
Version:        44.4
Release:        1.1
Summary:        A simple user-friendly terminal emulator for the GNOME desktop
License:        GPL-3.0-only
URL:            https://gitlab.gnome.org/GNOME/console
Source:         %{name}-%{version}.tar.xz

BuildRequires:  appstream-glib
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  desktop-file-utils
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.59.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.72
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.72
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.2.beta
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libpcre2-8) >= 10.32
BuildRequires:  pkgconfig(vte-2.91-gtk4) >= 0.69.91

Obsoletes:      nautilus-extension-console < %{version}
Provides:       nautilus-extension-console = %{version}

%description
A simple user-friendly terminal emulator for the GNOME desktop.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang kgx %{?no_lang_C} %{name}.lang

%check
%meson_test

%files
%license COPYING
%doc README.md
%{_bindir}/kgx
%{_datadir}/applications/org.gnome.Console.desktop
%{_datadir}/dbus-1/services/org.gnome.Console.service
%{_datadir}/glib-2.0/schemas/org.gnome.Console.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Console.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Console-symbolic.svg
%{_datadir}/metainfo/org.gnome.Console.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sun Aug  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.4:
  + Updated translations.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Updated translations.
* Wed Feb 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Up to date with libadwaita changes, including the new tab
    overview that replaces the existing mobile switcher, and
    supplements the tab bar.
  + Cleanups for ‘Find’.
  + Expand the scenarios considered to be ‘remote’ to include mosh
    and waypipe.
  + Other assorted fixes.
  + Updated translations.
- Drop 66b225e.patch: Fixed upstream.
* Thu Jan 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 66b225e.patch: style: Use accent_fg_color properly.
* Sun Sep 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sat Sep  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + Take advantage of some newer GLib/GObject features, with a
    corresponding dependency bump, to simplify some code.
  + Store the size of the last window, and use it for future
    windows rather than unconditionally using 80×24.
  + A bug in 43.beta where ‘Show in Files’ was mistakenly
    unavailable has been fixed, as well as a longstanding edge case
    when a background tab closes,
  + Updated translations.
- Drop fix-werror.patch: Fixed upstream.
- Replace pkgconfig(vte-2.91) with pkgconfig(vte-2.91-gtk4)
  BuildRequires following upstream changes.
* Tue Aug  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Port to Gtk4/Adwaita, taking advantage of Adwaita's recolouring
    features and thus removing our dependency on sassc. We now
    require that Vte is be built with gtk4 support.
  + Nautilus Plug-in has been moved upstream. Improved our
    handeling of custom shells/commands, fixing several bugs and
    providing a more predictable experience.
  + Provide fixes for drag-n-drop, with local URIs now being
    converted to regular fileystem paths.
  + Assorted other fixes were contributed, including detection of
    man page links, keyboard shortcuts, clipboard oddities,
    building with clang, and assorted ancillary data updates.
  + Updated translations.
- Changes in BuildRequires following upstream changes:
  + Drop sassc, pkgconfig(gtk+-3.0), pkgconfig(libhandy-1) and
    pkgconfig(libnautilus-extension).
  + Add pkgconfig(gtk4) and pkgconfig(libadwaita-1).
- Drop sub-package nautilus-extension-console, no longer built.
- Add fix-werror.patch: Hack around a bit too agressive werror,
  drop before sub to factory!
* Thu Jul 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.2:
  + Fix GCC warning.
  + Check for pcre2 during configure.
- Changes from version 42.1:
  + Fixed release notes in metainfo.
- Add explicit pkgconfig(libpcre2-8) BuildRequires, meson checks
  for it.
* Wed Jul 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Drop unneeded custom RPATH.
  + Updated translations.
* Tue Feb 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + KGX now goes by Console and we have restored the legendary
    ‘Day’ mode.
  + Also in this release:
  - 👓 Much better High Contrast support
  - 🔬 Increased Zoom range
  - 📋 Paste is now less pernickety
  - 🩹 Fixed a couple leaks and assorted issues
  + Updated translations.
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Initial build for openSUSE.
